@@ -5,13 +5,13 @@
 
 # Internal helper function to compute beta OLS
 beta_ols <- function(X, Y) {
-  solve(t(X) %*% X) %*% t(X) %*% Y
-  # inv_X <- ginv(t(X) %*% X)
-  # inv_X %*% t(X) %*% Y
+  #solve(t(X) %*% X) %*% t(X) %*% Y
+  inv_X <- ginv(t(X) %*% X)
+  inv_X %*% t(X) %*% Y
 }
 
 # Internal function: Multiple-blocks MLDFM computation
-multiple_blocks<-function(Yorig, r, block_ind, tol, max_iter, method){
+multiple_blocks<-function(Yorig, global, local, middle_layer, block_ind, tol, max_iter, method){
 
  
   # Standardize the original data
@@ -21,8 +21,7 @@ multiple_blocks<-function(Yorig, r, block_ind, tol, max_iter, method){
   results <- list()  # List to save results
   num_blocks <- length(block_ind) # Number of blocks
   num_obs <- nrow(Yorig) # Total number of observations
-  num_factors <- sum(r) # Total number of factors
-  
+
   
   # Define block ranges and count the number of variables in each block
   ranges <- list()
@@ -39,17 +38,24 @@ multiple_blocks<-function(Yorig, r, block_ind, tol, max_iter, method){
   }
   
   
+  
+  # Define factor list structure
+  r_list <- build_factor_structure(global = global, local = local, middle_layer = middle_layer, num_blocks)
+  
+  
+  
+  
   # --- STEP 1: INITIAL FACTORS ---
   init_res <- compute_initial_factors(
     Yorig, num_vars, num_obs, num_blocks,
-    ranges, num_factors, r, method
+    ranges, r_list, method
   )
   InitialFactors <- init_res$InitialFactors
   Factor_list <- init_res$Factor_list
   
   
   
- 
+  
   # --- STEP 2: ITERATIVE OPTIMIZATION ---
   RSS_previous <- Inf
   iteration <- 0
@@ -60,7 +66,8 @@ multiple_blocks<-function(Yorig, r, block_ind, tol, max_iter, method){
     if (iteration > max_iter) break
     
     # Compute/Update Lambda
-    L_res <- compute_lambda(Yorig, num_blocks, ranges, num_factors, r, Factor_list, Loadings_list)
+    L_res <- compute_lambda(Yorig, num_blocks, ranges, r_list, Factor_list, Loadings_list)
+    
     Lambda <- L_res$Lambda
     Loadings_list <- L_res$Loadings_list
     
@@ -70,7 +77,7 @@ multiple_blocks<-function(Yorig, r, block_ind, tol, max_iter, method){
     # FinalFactors <- t(inv_LtL %*% Lambda %*% t(Yorig))
     
     # Update factor list
-    Factor_list <- update_factor_list(Factor_list, FinalFactors, r)
+    Factor_list <- update_factor_list(Factor_list, FinalFactors, r_list)
     
     # Compute RSS and check convergence
     FinalResiduals <- Yorig - FinalFactors %*% Lambda
@@ -87,9 +94,11 @@ multiple_blocks<-function(Yorig, r, block_ind, tol, max_iter, method){
 
   }
   
+  
+  
   # --- STEP 3: IDENTIFICATION ---
   Id_res <- apply_identifications(
-    Yorig, num_blocks, ranges, num_factors, r,
+    Yorig, num_blocks, ranges, r_list,
     FinalFactors, Factor_list, Loadings_list
   )
   orthogonal_FinalFactors <- Id_res$FinalFactors
@@ -97,27 +106,12 @@ multiple_blocks<-function(Yorig, r, block_ind, tol, max_iter, method){
   Lambda <- Id_res$Lambda
 
   
-  
-  
   # Final residuals
   Residuals <- Yorig - orthogonal_FinalFactors %*% Lambda
   
-  
-  # Build named factor list
-  Final_list <- list()
-  for (key in names(Factor_list)) {
-    Final_list[[key]] <- ncol(Factor_list[[key]])
-  }
-  
-  
-  # Compute Factors_hat
-  #Factors_hat <- compute_factors_hat2(Yorig, ranges, Factor_list,Loadings_list)
-
-  
   # Drop column names
   orthogonal_FinalFactors <- unname(orthogonal_FinalFactors)
   
-  
   # Collect results
   results$Factors <- orthogonal_FinalFactors
   results$Lambda <- t(Lambda)
@@ -128,7 +122,7 @@ multiple_blocks<-function(Yorig, r, block_ind, tol, max_iter, method){
     results$Method <- "PCA"
   }
   results$Iterations <- iteration
-  results$Factors_list <- Final_list
+  results$Factors_list <- r_list
   
  
   return(results)
