@@ -41,10 +41,15 @@ data <- outliers_result$data
 # 3 blocks
 n_blocks <- 3 # 63 248 208
 block_ind <- c(63,311,519)
-r <- c(1,0,1,0,1,1,1)
+global = 1
+local = c(1,1,1)
+middle_layer <- list("1-3" = 1)
+
 
 mldfm_result <- mldfm(data, 
-                      r=r, 
+                      globa = global,
+                      local = local,
+                      middle_layer = middle_layer,
                       blocks = n_blocks, 
                       block_ind = block_ind , 
                       tol = 1e-6, 
@@ -60,7 +65,9 @@ mldfm_result <- mldfm(data,
 n_samples <- 100
 sample_size <- 0.9
 mldfm_subsampling_result <- mldfm_subsampling(data, 
-                                         r=r, 
+                                         global = global, 
+                                         local = local,
+                                         middle_layer = middle_layer,
                                          blocks = n_blocks, 
                                          block_ind = block_ind , 
                                          tol = 1e-6, 
@@ -125,32 +132,3 @@ GiS0.75 <- quantile_risk(scenario_density, QTAU = 0.75)
 GiS0.95 <- quantile_risk(scenario_density, QTAU = 0.95)
 
 
-## -----------------------------------------------------------------------------
-# Final GaR and GiS plot
-library(ggplot2)
-time <- dates[-1]
-
-MLGaRGiS <- data.frame(
-  time = time,
-  dep_variable = as.vector(dep_variable[2:59]),
-  GaR.05 = as.vector(GaR0.05[1:58]),
-  GaR.95 = as.vector(GaR0.95[1:58]),
-  GiS.05 = as.vector(GiS0.05[1:58]), 
-  GiS.25 = as.vector(GiS0.25[1:58]),
-  GiS.75 = as.vector(GiS0.75[1:58]),
-  GiS.95 = as.vector(GiS0.95[1:58])
-)
-
-
-p <- ggplot(MLGaRGiS,aes(x=time,y=dep_variable)) + 
-  geom_line() + theme_bw()+
-  geom_ribbon(aes(ymin=GiS.05,ymax=GiS.95), alpha=0.1, fill="red") +
-  geom_ribbon(aes(ymin=GiS.25,ymax=GiS.75), alpha=0.1, fill="grey10") +
-  geom_line(aes(x=time, GaR.05), linewidth=0.1, colour="black", linetype="dashed") +
-  geom_line(aes(x=time, GaR.95), linewidth=0.1, colour="black", linetype="dashed") +
-  scale_y_continuous("Growth") +
-  scale_x_date(date_labels = "%Y", date_breaks = "2 years") +
-  theme(axis.text.x = element_text(angle = 90))
-fig <- plotly::ggplotly(p)
-#fig
-
